==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/ec2/kotlin/inputs/LaunchTemplateCreditSpecificationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.ec2.kotlin.inputs

import com.pulumi.aws.ec2.inputs.LaunchTemplateCreditSpecificationArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property cpuCredits The credit option for CPU usage.
 * Can be `standard` or `unlimited`.
 * T3 instances are launched as `unlimited` by default.
 * T2 instances are launched as `standard` by default.
 */
public data class LaunchTemplateCreditSpecificationArgs(
    public val cpuCredits: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.aws.ec2.inputs.LaunchTemplateCreditSpecificationArgs> {
    override fun toJava(): com.pulumi.aws.ec2.inputs.LaunchTemplateCreditSpecificationArgs =
        com.pulumi.aws.ec2.inputs.LaunchTemplateCreditSpecificationArgs.builder()
            .cpuCredits(cpuCredits?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [LaunchTemplateCreditSpecificationArgs].
 */
@PulumiTagMarker
public class LaunchTemplateCreditSpecificationArgsBuilder internal constructor() {
    private var cpuCredits: Output<String>? = null

    /**
     * @param value The credit option for CPU usage.
     * Can be `standard` or `unlimited`.
     * T3 instances are launched as `unlimited` by default.
     * T2 instances are launched as `standard` by default.
     */
    @JvmName("hmukbbpinfsxwjhh")
    public suspend fun cpuCredits(`value`: Output<String>) {
        this.cpuCredits = value
    }

    /**
     * @param value The credit option for CPU usage.
     * Can be `standard` or `unlimited`.
     * T3 instances are launched as `unlimited` by default.
     * T2 instances are launched as `standard` by default.
     */
    @JvmName("mgkqgdijgoxgwavp")
    public suspend fun cpuCredits(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.cpuCredits = mapped
    }

    internal fun build(): LaunchTemplateCreditSpecificationArgs =
        LaunchTemplateCreditSpecificationArgs(
            cpuCredits = cpuCredits,
        )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/ec2/kotlin/inputs/LaunchTemplateCreditSpecificationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.ec2.kotlin.inputs

import com.pulumi.aws.ec2.inputs.LaunchTemplateCreditSpecificationArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property cpuCredits The credit option for CPU usage.
 * Can be `standard` or `unlimited`.
 * T3 instances are launched as `unlimited` by default.
 * T2 instances are launched as `standard` by default.
 */
public data class LaunchTemplateCreditSpecificationArgs(
    public val cpuCredits: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.aws.ec2.inputs.LaunchTemplateCreditSpecificationArgs> {
    override fun toJava(): com.pulumi.aws.ec2.inputs.LaunchTemplateCreditSpecificationArgs =
        com.pulumi.aws.ec2.inputs.LaunchTemplateCreditSpecificationArgs.builder()
            .cpuCredits(cpuCredits?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [LaunchTemplateCreditSpecificationArgs].
 */
@PulumiTagMarker
public class LaunchTemplateCreditSpecificationArgsBuilder internal constructor() {
    private var cpuCredits: Output<String>? = null

    /**
     * @param value The credit option for CPU usage.
     * Can be `standard` or `unlimited`.
     * T3 instances are launched as `unlimited` by default.
     * T2 instances are launched as `standard` by default.
     */
    @JvmName("xchuggrkghyhcfsp")
    public suspend fun cpuCredits(`value`: Output<String>) {
        this.cpuCredits = value
    }

    /**
     * @param value The credit option for CPU usage.
     * Can be `standard` or `unlimited`.
     * T3 instances are launched as `unlimited` by default.
     * T2 instances are launched as `standard` by default.
     */
    @JvmName("gmshwmlmomjembmx")
    public suspend fun cpuCredits(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.cpuCredits = mapped
    }

    internal fun build(): LaunchTemplateCreditSpecificationArgs =
        LaunchTemplateCreditSpecificationArgs(
            cpuCredits = cpuCredits,
        )
}
